package com.casic.missiles.modular.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.casic.missiles.core.datascope.DataScope;
import com.casic.missiles.model.response.ResponseData;
import com.casic.missiles.modular.system.dto.ExcelModel.*;
import com.casic.missiles.modular.system.dto.statistic.*;
import com.casic.missiles.modular.system.model.BusWellInfo;

import java.util.List;

/**
 * 数据统计服务接口
 *
 * @author zyn
 */
public interface DeviceDataListService extends IService<BusWellInfo> {

    /**
     * 开挖监测仪数据查询
     */
    List<DataDig> selectDigDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    /**
     * 根据条件检索井盖监测数据列表
     */
    List<DataWellCover> selectWellDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    /**
    * 根据检索条件查询液位检测数据
    */
    List<DataLiquid> selectLiquidDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);
    /**
     * 燃气数据查询
     */
    List<DataGas> selectGasDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);
    /**
     * 噪声记录仪数据查询
     */
    List<DataNoise> selectNoiseDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);
    /**
     * 有害气体数据查询
     */
    List<DataHarmfulGas> selectHarmfulDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);
    /**
     * 温湿度数据查询
     */
    List<DataTempHum> selectTempDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);
    /**
     * 井盖定位监测仪数据查询
     */
    List<DataWellCoverLoca> selectWellLocDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    List<DataGasLiquid> selectGasLiquidDataScope(DataScope dataScope, String sensorType, String devcode, String beginTime, String endTime, String wellCode);
    /**
     * 管盯数据查询
     */
    List<DateTube> selectTubeDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    List<DataHydrant> getHydrantlist(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    List<DataH2s> getH2sDataScope(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    List<DataGasdector> getGasdectorList(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);

    List<DataPantilt> getPantiltList(DataScope dataScope, String devcode, String beginTime, String endTime, String wellCode);


}